#----------------------------------------------------------------------------------#
#
# FILE:			script.py
# AUTHOR:		Peter Quinn
# DATE:			10.02.2005
# VERSION:		1.00
#
# DESCRIPTION:	HyperTail File Input Interface system.
#
# INTERFACE:	
#
#----------------------------------------------------------------------------------#

file		= ""
selfile		= ""
status		= ""
filetype	= ""
delete		= False
colour		= "#FFFFFF"
file_list	= get_config("filelist")
cmd_list	= get_config("cmdlist")

logging		= False
logfile		= ""
command		= ""
parameter	= ""
useconsole	= True
actiontype	= "0"


#----------------------------------------------------------------------------------#
#
# PREFERENCES:
#
# Preferences Call-back
#
def file_prefs(key, value):

	if		key == "file":			add_file(value)
	elif	key == "selfile":		select_file(value)
	elif	key == "delete":		del_file(value)
	elif	key == "colour":		set_colour(value)

	elif	key == "logging":		set_logging(value)
	elif	key == "logfile":		set_logfile(value)
	elif	key == "command":		set_command(value)
	elif	key == "parameter":		set_parameter(value)
	elif	key == "useconsole":	set_useconsole(value)
	elif	key == "actiontype":	set_actiontype(value)


#----------------------------------------------------------------------------------#
#
# FILE INPUT INTERFACE:
#
# Delete an entry in the enum
#
def del_file(value):

	global file_list, cmd_list

	n = Prefs.files.selection

	if value == True:

		tmp = buffer.read_all

		for i in range(len(tmp)):
			if tmp[i][2] == n:
				tmp = [buffer.filltype] + tmp[:i] + tmp[i + 1:]
				
			if tmp[i][2] > n:
				(txt, original, index, colour, linenum, file) = tmp[i]
				tmp[i] = (txt, original, index - 1, colour, linenum - 1, file)
		
		buffer.cursor = 0
		buffer.write = tmp

		refresh_buffer()
		tail.del_file = file_list[n]
		
		file_list	= file_list[:n] + file_list[n + 1:]
		cmd_list	= cmd_list[:n] + cmd_list[n + 1:]
		
		Prefs.files.items = file_list
		Prefs.logfile.items = file_list

		set_config("filelist", file_list)
		set_config("cmdlist", cmd_list)
		
		n = len(file_list)
		Dsp.watches2.value = n

		if n == 0:
			Dsp.updated2.value		= ""
			Prefs.filetype.value	= ""
			Prefs.status.value		= ""
		
		set_status()

	Prefs.delete.value = False


#
# Add an entry to the enum
#
def add_file(value):

	global file_list, cmd_list

	file_list	= get_config("filelist")
	cmd_list	= get_config("cmdlist")

	if not file_list:
		file_list	= []
		cmd_list	= []

	if value:
		for i in range(len(file_list)):
			(file, colour) = file_list[i]
			if file == value:
				Prefs.filetype.value = ""
				Prefs.status.value = "File already in list"
				return
	
		file_list.append((value, "#FFFFFF"))
		cmd_list.append((0, False, "", ""))
		
		Prefs.files.items = file_list
		Prefs.logfile.items = file_list
		
		Prefs.delete.value = False
		Prefs.files.selection = len(file_list) - 1
		Prefs.file.value = ""
		
		tail.add_file = (value, "#FFFFFF")
		get_fileattributes((value, ""))
		
		set_config("filelist", file_list)
		set_config("cmdlist", cmd_list)

	Dsp.watches2.value = len(file_list)
	set_status()


#
# Set the colour of the currently selected file
#
def set_colour(value):

	global file_list

	n = Prefs.files.selection

	if len(file_list) > 0:
		(filename, colour) = file_list[n]
		file_list[n] = (filename, value)
		
		tail.set_colour = (filename, value)
		set_config("filelist", file_list)

		refresh_buffer()

	
#
# Sets the colour based on the currently selected file
#
def select_file(value):

	global file_list

	n = Prefs.files.selection

	if len(file_list) > 0:
		(filename, colour) = file_list[n]

		Prefs.colour.value = colour
		get_fileattributes((filename, colour))


#
# Set the enable/disable status of the file input interface
#
def set_status():

	global file_list

	if len(file_list) == 0:
		Prefs.colour.value		= "#FFFFFF"
		Prefs.files.enabled		= False
		Prefs.colour.enabled	= False
		Prefs.delete.enabled	= False
	else:
		Prefs.files.enabled		= True
		Prefs.colour.enabled	= True
		Prefs.delete.enabled	= True


#
#
#
def get_fileattributes(file):

	tail.select_file		= file
	Prefs.filetype.value	= tail.get_filetype
	Prefs.status.value		= tail.get_status


#----------------------------------------------------------------------------------#
#
#
#
#
#
#
#
def set_command(value):

	command = value

	if len(cmd_list) > 0:
		n = Prefs.logfile.selection
		cmd_list[n] = (Prefs.actiontype.selection, Prefs.useconsole.value, command, Prefs.parameter.value)

		set_config("cmdlist", cmd_list)


#
#
#
def set_parameter(value):

	parameter = value

	if len(cmd_list) > 0:
		n = Prefs.logfile.selection
		cmd_list[n] = (Prefs.actiontype.selection, Prefs.useconsole.value, Prefs.command.value, parameter)

		set_config("cmdlist", cmd_list)


#
#
#
def set_logging(value):

	if len(file_list) == 0:
		value = False
		Prefs.logging.value		= False

	logging = value

	Prefs.logfile.enabled		= logging
	Prefs.actiontype.enabled	= logging

	if logging:
		set_actiontype(actiontype)
	else:
		Prefs.useconsole.enabled	= False
		Prefs.command.enabled		= False
		Prefs.parameter.enabled		= False


#
#
#
def set_logfile(value):

	n = Prefs.logfile.selection

	if len(cmd_list) > 0:
		(action, console, command, parameter) = cmd_list[n]
	
		Prefs.command.value			= command
		Prefs.parameter.value		= parameter
		Prefs.actiontype.selection	= action
		Prefs.useconsole.value		= console


#
#
#
def set_useconsole(value):

	useconsole = value

	if len(cmd_list) > 0:
		cmd_list[Prefs.logfile.selection] = (Prefs.actiontype.selection, useconsole, Prefs.command.value, Prefs.parameter.value)


#
#
#
def set_actiontype(value):

	actiontype = value

	if		actiontype == "0":
		if logging:
			Prefs.useconsole.enabled	= False
			Prefs.command.enabled		= False
			Prefs.parameter.enabled		= False
		Prefs.useconsole.value	= False
		Prefs.command.value		= ""
		Prefs.parameter.value	= ""
	elif	actiontype == "1":
		if logging:
			Prefs.useconsole.enabled	= False
			Prefs.command.enabled		= False
			Prefs.parameter.enabled		= False
		Prefs.useconsole.value	= True
		Prefs.command.value		= "whois"
		Prefs.parameter.value	= "SRC=<ipaddress>"
	elif	actiontype == "2":
		if logging:
			Prefs.useconsole.enabled	= False
			Prefs.command.enabled		= True
			Prefs.parameter.enabled		= False
		Prefs.useconsole.value	= False
		Prefs.command.value		= "gvim"
		Prefs.parameter.value	= ""
	elif	actiontype == "3":
		if logging:
			Prefs.useconsole.enabled	= True
			Prefs.command.enabled		= True
			Prefs.parameter.enabled		= True
		if len(cmd_list) > 0:
			(a, console, command, parameter) = cmd_list[Prefs.logfile.selection]
			Prefs.useconsole.value		= console
			Prefs.command.value			= command
			Prefs.parameter.value		= parameter
		else:
			Prefs.useconsole.value		= False
			Prefs.command.value			= ""
			Prefs.parameter.value		= ""

	
#----------------------------------------------------------------------------------#

if not file_list:
	file_list	= []
	set_status()
else:
	for i in file_list:
		tail.add_file = i


Prefs.files.items	= file_list
Prefs.logfile.items	= file_list

