#----------------------------------------------------------------------------------#
#
# THEME PREFERENCES
#
# FILE:			theme.py
# AUTHOR:		Peter Quinn
# DATE:			10.02.2005
# VERSION:		1.2
#
# DESCRIPTION:	General theme preferences for desklet displays.
#
#----------------------------------------------------------------------------------#

bordertype		= "light"
borderindex		= 1
background		= ""
bgcolour		= "#275B793C"

bordertop		= True
borderbottom	= True
borderleft		= True
borderright		= True

toppadding		= 0
bottompadding	= 0
leftpadding		= 0
rightpadding	= 0

bordersize		= 	[
						[Unit(0, PX), Unit(0, PX), Unit(0, PX), Unit(0, PX)],
						[Unit(15, PX), Unit(9, PX), Unit(15, PX), Unit(19, PX)],
						[Unit(5, PX), Unit(5, PX), Unit(5, PX), Unit(5, PX)],
						[Unit(7, PX), Unit(7, PX), Unit(7, PX), Unit(7, PX)],
						[Unit(9, PX), Unit(9, PX), Unit(9, PX), Unit(9, PX)],
						[Unit(17, PX), Unit(17, PX), Unit(17, PX), Unit(17, PX)],
					]

					
#----------------------------------------------------------------------------------#
#
# PREFERENCES CALLBACK
#
#
def theme_prefs(key, value):

	if		key == "bordertype":		set_bordertype(value)
	elif	key == "bordertop":			set_bordertop(value)
	elif	key == "borderbottom":		set_borderbottom(value)
	elif	key == "borderleft":		set_borderleft(value)
	elif	key == "borderright":		set_borderright(value)
	elif	key == "bgcolour":			set_bgcolour(value)
	elif	key == "background":		set_background(value)
	elif	key == "toppadding":		set_toppadding(value)
	elif	key == "bottompadding":		set_bottompadding(value)
	elif	key == "leftpadding":		set_leftpadding(value)
	elif	key == "rightpadding":		set_rightpadding(value)
	elif	key == "width":				set_width(value)
	elif	key == "height":			set_height(value)


#----------------------------------------------------------------------------------#
#
# Sets the type of border.
#
def set_bordertype(value):

	global borderindex

	bordertype = value

	uris =	[
				"gfx/borders/%s/left.png" % bordertype,
				"gfx/borders/%s/top.png" % bordertype,
				"gfx/borders/%s/right.png" % bordertype,
				"gfx/borders/%s/bottom.png" % bordertype,
				"gfx/borders/%s/top-left.png" % bordertype,
				"gfx/borders/%s/top-right.png" % bordertype,
				"gfx/borders/%s/bottom-right.png" % bordertype,
				"gfx/borders/%s/bottom-left.png" % bordertype
			]

	uris = [str(x) for x in uris]

	if value == "none":
		Prefs.bordertop.enabled		= False
		Prefs.borderbottom.enabled	= False
		Prefs.borderleft.enabled	= False
		Prefs.borderright.enabled	= False
	else:
		Prefs.bordertop.enabled		= True 
		Prefs.borderbottom.enabled	= True
		Prefs.borderleft.enabled	= True
		Prefs.borderright.enabled	= True
	
	if value == "none":
		borderindex = 0
	elif value == "dark":
		borderindex = 1
	elif value == "light":
		borderindex = 1
	elif value == "lt" or value == "round" or value == "tmkt":
		borderindex = 2
	elif value == "black-big" or value == "white-big":
		borderindex = 3
	elif value == "black-ext" or value == "white-ext":
		borderindex = 4
	else:
		borderindex = 5
	
	Dsp.border.border_width = bordersize[borderindex]
	Dsp.border.border_uris = uris

	set_border()


#----------------------------------------------------------------------------------#
#
# BORDER PADDING PREFERENCES
#
#
# Sets the padding at the top of the display
#
def set_toppadding(value):

	toppadding = value
	Dsp.toppadding.height = Unit(value, PX)


#
# Sets the padding at the bottom of the display
#
def set_bottompadding(value):
	
	bottompadding = value
	Dsp.bottompadding.height = Unit(value, PX)


#
# Sets the padding at the left of the display
#
def set_leftpadding(value):

	leftpadding = value
	Dsp.leftpadding.width = Unit(value, PX)


#
# Sets the padding at the right of the display
#
def set_rightpadding(value):

	rightpadding = value
	Dsp.rightpadding.width = Unit(value, PX)


#----------------------------------------------------------------------------------#
#
# BORDER VISIBILITY PREFERENCES
#
# Sets the border around the applet.
#
def set_border():

	global borderindex
	
	b = bordersize[borderindex][:]
	
	if not bordertop:
		b[1] = Unit(0, PX)
	if not borderbottom:
		b[3] = Unit(0, PX)
	if not borderleft:
		b[0] = Unit(0, PX)
	if not borderright:
		b[2] = Unit(0, PX)

	Dsp.border.border_width = b


#
# Sets the top border
#
def set_bordertop(value):

	bordertop = value
	set_border()


#
# Sets the bottom border
#
def set_borderbottom(value):

	borderbottom = value
	set_border()


#
# Sets the left border
#
def set_borderleft(value):

	borderleft = value
	set_border()


#
# Sets the right border
#
def set_borderright(value):

	borderright = value
	set_border()


#----------------------------------------------------------------------------------#
#
# BORDER PREFERENCES METHODS
#
#
# Sets the background colour of the display.
#
def set_bgcolour(value):
	
	bgcolour = value
	Dsp.panel.bg_color = bgcolour

	
#
# Sets the background image of the display
#
def set_background(value):

	if value:
		Dsp.panel.bg_uri = value


#
# Sets the width of the display
#
def set_width(value):

	width = value
	
	Dsp.body.width = Unit(width, PX)
	Dsp.topseparator.width = Unit(width, PX)
	Dsp.bottomseparator.width = Unit(width, PX)
	Prefs.con_width.max = width


#
# Sets the height of the display
#
def set_height(value):

	pass


#----------------------------------------------------------------------------------#

